<?php
/**
 * Vehicle Builds Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Builds {

    private $helper;
    private $vehicle_type;
    private $use_cache;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];
        $this->vehicle_type = $this->helper->translate_vehicle_type($vehicle_type);
    }
    

     /***
    *
    * Get a list with vehicle builds
    *
    ***/
    public function getBuilds($serieId = NULL, $brandSlug = NULL, $serieSlug = NULL) {
        if (isset($serieId) || (isset($brandSlug) && isset($serieSlug))) {
            $cacheCode = $this->vehicle_type . '_builds_' . base64_encode($brandSlug . '_' . $serieId .'_'. $serieSlug);
            $buildCache = $this->helper->get_cache($cacheCode);
            
            if(false !== $buildCache && $this->use_cache == 1) {
                // if((isset($buildCache[0]['medium'])) && ($buildCache[0]['medium'] !== '')) {
                    return $buildCache;
                // }
            }
            
            global $wpdb;
            $catalogData = null;
            $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
            $url = (isset($serieSlug)) ? API_SEARCH_URL . '?type='. $this->vehicle_type .'&brand_slug=' . $brandSlug .'&serie_slug=' . $serieSlug : API_URL . 'builds?serie_id=' . $serieId;
            
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            if (is_wp_error( $response )) {
               $error_message = $response->get_error_message();
               echo "Something went wrong: $error_message";
            } else {
               $responseData = json_decode($response['body'], true);
               $this->helper->set_cache($cacheCode, $responseData, 'ctr', 28800); // Save our builds for at least 8 hours
               return $responseData;
            }
        }
    }

}